# Knowledgelinks.io BIBCAT 2.0

[![Build Status](https://travis-ci.org/KnowledgeLinks/rdfw-bibcat.svg)](https://travis-ci.org/KnowledgeLinks/rdfw-bibcat)


## Installation
The easiest way to get started with `bibcat` is to install with **pip**:

    pip install bibcat

You can also clone this repository and run pip from the same directory:

    git clone https://github.com/KnowledgeLinks/rdfw-bibcat bibcat
    cd bibcat
    pip install .

If you don't have pip available (although you should because `bibcat` is targeted for Python 3.5+)
you can also follow the same steps to clone `bibcat` but run `python setup.py install`.    
